#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 22/10/2002
#################################################################################
#
# Configure Ignore - Script part of Webchat designed to configure ignore lists
# Copyright (C) 2000-2002  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 204 - 817, 5th Street NE
#                 Calgary, Alberta
#                 T2E 3W9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler
use Ethereal::Login;						# Login functionality
use Ethereal::Param;						# Parameter control
use Ethereal::Table;						# Table control
use Ethereal::Template;						# Template handler


#################################################################################
# Data Members
#################################################################################
my $database;							# Database handle
my $cgi;							# Common gateway interface handle
my $login;							# Login handle
my $param;							# Parameter Handle

my %config;							# Configuration tag

#################################################################################
# Program Area
#################################################################################

	# Initial handles
	$cgi      = new CGI;
	$database = new Ethereal::Database();
	$param    = new Ethereal::Param();

	# Connect and fetch
	$database->Connect();
	$param->GetParam($cgi);

	# Retreive hash
	$database->GetHashConfiguration(\%config);
	

	# Document header
	print $cgi->header();
	$database->DocumentGetHeader();

	# Login handle
	$login = new Ethereal::Login($database, $cgi, $param);

	# Authenthication
	if ($login->GetVerificationNormal())
	{
		# Screen display
		InitialDisplay($database, $cgi, $param, \%config);
	}

	# Document footer
	$database->DocumentGetFooter($database);

#################################################################################
# Sub-Routines
#################################################################################

#####################
# InitialDisplay
#
# Handles the general output of the initial display screen.  Which will allow one
# to change password, E-Mail addresses and/or passwords.

sub InitialDisplay						# Database, CGI, Param
{
	#####################
	# Data members
	my $database = shift;					# Database handle
	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter handle
	my $config   = shift;					# Configuration hash

	my $data     = $database->{'HANDLE'};			# Database connection handle
	my $table    = new Ethereal::Table();			# Table handle
	my $tmpl     = new Ethereal::Template($config);		# Template handle

	my $choice;						# Choice of the matter	
	my $ignored;						# List of the dammed
	my @ignored;						# List of the dammed
	

	#####################
	# Program area	
	
	# Information handling
	# Addition into list
	if (defined($param->{$config->{'TxtSubmitAddition'}}))
	{
		# Determine existence
		($choice) = $database->DataGet('SELECT PuppetName FROM Puppet WHERE PuppetName=?', $param->{'LIST'});

		# Verification
		if ((length($param->{'LIST'}) > 2) && ($param->{'LIST'} !~ /^\s/) && (defined($choice)))
		{
			# Insert information
			$data->do("INSERT INTO PuppetIgnore 
				(PuppeteerLogin,
				 PuppetName)
				VALUES (?,?)", {}, 
		 	$param->{'USER'}, 
			$param->{'LIST'});
		}

	}

	# Removal from list
	elsif (defined($param->{$config->{'TxtSubmitDelete'}}))
	{
		# Remove ignored person
		$data->do("DELETE FROM PuppetIgnore 
			WHERE PuppeteerLogin=? 
			  AND PuppetName=?", {}, 
		 $param->{'USER'}, 
		 $param->{'IGNORE'});
	}

	# Cleanup
	$param->Cleanup(
		$config->{'TxtSubmitAddition'},
		$config->{'TxtSubmitDelete'}
	 );

	
	# Retreive lists and adjust widgets
	$database->GetListPuppetIgnored(\@ignored, $param->{'USER'});
	$ignored = $cgi->scrolling_list('IGNORE', \@ignored, $ignored[0], 10);

	# Title
	$tmpl->ShowMain($config->{'TagIgnoreTitle'});

	# Ignore list
	print $cgi->start_form();
	print $param->EmbedNormal($cgi, %{$param}), "\n";

	# Display of information
	$table->MakeTop();

	# Additions
	$table->MakeSingle($tmpl->PassSub($config->{'TagIgnoreAdd'}));
	$table->MakeValid(
	 $cgi->textfield('LIST', '', 20, 30),
	 $cgi->submit($config->{'TxtSubmitAddition'}),
	 'middle');
	$table->MakeBlank();

	# Removal
	$table->MakeSingle($tmpl->PassSub($config->{'TagIgnoreRem'}));
	$table->MakeValid($ignored,
	 $cgi->submit($config->{'TxtSubmitDelete'}),
	 'middle');
	$table->MakeBottom();

	# From bottom
	print $cgi->end_form(), "\n";
}
